[
          {
            'number' => '1',
            'unicode' => 'E63E',
            'name' => '晴れ',
            'sjis' => 'F89F',
            'name_en' => 'Fine',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/1.gif'
          },
          {
            'number' => '2',
            'unicode' => 'E63F',
            'name' => '曇り',
            'sjis' => 'F8A0',
            'name_en' => 'Cloudy',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/2.gif'
          },
          {
            'number' => '3',
            'unicode' => 'E640',
            'name' => '雨',
            'sjis' => 'F8A1',
            'name_en' => 'Rain',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/3.gif'
          },
          {
            'number' => '4',
            'unicode' => 'E641',
            'name' => '雪',
            'sjis' => 'F8A2',
            'name_en' => 'Snow',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/4.gif'
          },
          {
            'number' => '5',
            'unicode' => 'E642',
            'name' => '雷',
            'sjis' => 'F8A3',
            'name_en' => 'Thunder',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/5.gif'
          },
          {
            'number' => '6',
            'unicode' => 'E643',
            'name' => '台風',
            'sjis' => 'F8A4',
            'name_en' => 'Typhoon',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/6.gif'
          },
          {
            'number' => '7',
            'unicode' => 'E644',
            'name' => '霧',
            'sjis' => 'F8A5',
            'name_en' => 'Fog',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/7.gif'
          },
          {
            'number' => '8',
            'unicode' => 'E645',
            'name' => '小雨',
            'sjis' => 'F8A6',
            'name_en' => 'Drizzle',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/8.gif'
          },
          {
            'number' => '9',
            'unicode' => 'E646',
            'name' => '牡羊座',
            'sjis' => 'F8A7',
            'name_en' => 'Aries',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/9.gif'
          },
          {
            'number' => '10',
            'unicode' => 'E647',
            'name' => '牡牛座',
            'sjis' => 'F8A8',
            'name_en' => 'Taurus',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/10.gif'
          },
          {
            'number' => '11',
            'unicode' => 'E648',
            'name' => '双子座',
            'sjis' => 'F8A9',
            'name_en' => 'Gemini',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/11.gif'
          },
          {
            'number' => '12',
            'unicode' => 'E649',
            'name' => '蟹座',
            'sjis' => 'F8AA',
            'name_en' => 'Cancer',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/12.gif'
          },
          {
            'number' => '13',
            'unicode' => 'E64A',
            'name' => '獅子座',
            'sjis' => 'F8AB',
            'name_en' => 'Leo',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/13.gif'
          },
          {
            'number' => '14',
            'unicode' => 'E64B',
            'name' => '乙女座',
            'sjis' => 'F8AC',
            'name_en' => 'Virgo',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/14.gif'
          },
          {
            'number' => '15',
            'unicode' => 'E64C',
            'name' => '天秤座',
            'sjis' => 'F8AD',
            'name_en' => 'Libra',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/15.gif'
          },
          {
            'number' => '16',
            'unicode' => 'E64D',
            'name' => '蠍座',
            'sjis' => 'F8AE',
            'name_en' => 'Scorpio',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/16.gif'
          },
          {
            'number' => '17',
            'unicode' => 'E64E',
            'name' => '射手座',
            'sjis' => 'F8AF',
            'name_en' => 'Sagittarius',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/17.gif'
          },
          {
            'number' => '18',
            'unicode' => 'E64F',
            'name' => '山羊座',
            'sjis' => 'F8B0',
            'name_en' => 'Capricorn',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/18.gif'
          },
          {
            'number' => '19',
            'unicode' => 'E650',
            'name' => '水瓶座',
            'sjis' => 'F8B1',
            'name_en' => 'Aquarius',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/19.gif'
          },
          {
            'number' => '20',
            'unicode' => 'E651',
            'name' => '魚座',
            'sjis' => 'F8B2',
            'name_en' => 'Pisces',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/20.gif'
          },
          {
            'number' => '21',
            'unicode' => 'E652',
            'name' => 'スポーツ',
            'sjis' => 'F8B3',
            'name_en' => 'Sports',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/21.gif'
          },
          {
            'number' => '22',
            'unicode' => 'E653',
            'name' => '野球',
            'sjis' => 'F8B4',
            'name_en' => 'Baseball',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/22.gif'
          },
          {
            'number' => '23',
            'unicode' => 'E654',
            'name' => 'ゴルフ',
            'sjis' => 'F8B5',
            'name_en' => 'Golf',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/23.gif'
          },
          {
            'number' => '24',
            'unicode' => 'E655',
            'name' => 'テニス',
            'sjis' => 'F8B6',
            'name_en' => 'Tennis',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/24.gif'
          },
          {
            'number' => '25',
            'unicode' => 'E656',
            'name' => 'サッカー',
            'sjis' => 'F8B7',
            'name_en' => 'Soccer',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/25.gif'
          },
          {
            'number' => '26',
            'unicode' => 'E657',
            'name' => 'スキー',
            'sjis' => 'F8B8',
            'name_en' => 'Ski',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/26.gif'
          },
          {
            'number' => '27',
            'unicode' => 'E658',
            'name' => 'バスケットボール',
            'sjis' => 'F8B9',
            'name_en' => 'Basketball',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/27.gif'
          },
          {
            'number' => '28',
            'unicode' => 'E659',
            'name' => 'モータースポーツ',
            'sjis' => 'F8BA',
            'name_en' => 'Motor sports',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/28.gif'
          },
          {
            'number' => '29',
            'unicode' => 'E65A',
            'name' => 'ポケットベル',
            'sjis' => 'F8BB',
            'name_en' => 'Pager',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/29.gif'
          },
          {
            'number' => '30',
            'unicode' => 'E65B',
            'name' => '電車',
            'sjis' => 'F8BC',
            'name_en' => 'Train',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/30.gif'
          },
          {
            'number' => '31',
            'unicode' => 'E65C',
            'name' => '地下鉄',
            'sjis' => 'F8BD',
            'name_en' => 'Subway',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/31.gif'
          },
          {
            'number' => '32',
            'unicode' => 'E65D',
            'name' => '新幹線',
            'sjis' => 'F8BE',
            'name_en' => 'Bullet train',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/32.gif'
          },
          {
            'number' => '33',
            'unicode' => 'E65E',
            'name' => '車（セダン）',
            'sjis' => 'F8BF',
            'name_en' => 'Car (sedan)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/33.gif'
          },
          {
            'number' => '34',
            'unicode' => 'E65F',
            'name' => '車（ＲＶ）',
            'sjis' => 'F8C0',
            'name_en' => 'Car (RV)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/34.gif'
          },
          {
            'number' => '35',
            'unicode' => 'E660',
            'name' => 'バス',
            'sjis' => 'F8C1',
            'name_en' => 'Bus',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/35.gif'
          },
          {
            'number' => '36',
            'unicode' => 'E661',
            'name' => '船',
            'sjis' => 'F8C2',
            'name_en' => 'Ship',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/36.gif'
          },
          {
            'number' => '37',
            'unicode' => 'E662',
            'name' => '飛行機',
            'sjis' => 'F8C3',
            'name_en' => 'Airplane',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/37.gif'
          },
          {
            'number' => '38',
            'unicode' => 'E663',
            'name' => '家',
            'sjis' => 'F8C4',
            'name_en' => 'House',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/38.gif'
          },
          {
            'number' => '39',
            'unicode' => 'E664',
            'name' => 'ビル',
            'sjis' => 'F8C5',
            'name_en' => 'Building',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/39.gif'
          },
          {
            'number' => '40',
            'unicode' => 'E665',
            'name' => '郵便局',
            'sjis' => 'F8C6',
            'name_en' => 'Post office',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/40.gif'
          },
          {
            'number' => '41',
            'unicode' => 'E666',
            'name' => '病院',
            'sjis' => 'F8C7',
            'name_en' => 'Hospital',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/41.gif'
          },
          {
            'number' => '42',
            'unicode' => 'E667',
            'name' => '銀行',
            'sjis' => 'F8C8',
            'name_en' => 'Bank',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/42.gif'
          },
          {
            'number' => '43',
            'unicode' => 'E668',
            'name' => 'ＡＴＭ',
            'sjis' => 'F8C9',
            'name_en' => 'ATM',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/43.gif'
          },
          {
            'number' => '44',
            'unicode' => 'E669',
            'name' => 'ホテル',
            'sjis' => 'F8CA',
            'name_en' => 'Hotel',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/44.gif'
          },
          {
            'number' => '45',
            'unicode' => 'E66A',
            'name' => 'コンビニ',
            'sjis' => 'F8CB',
            'name_en' => 'Convenience store',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/45.gif'
          },
          {
            'number' => '46',
            'unicode' => 'E66B',
            'name' => 'ガソリンスタンド',
            'sjis' => 'F8CC',
            'name_en' => 'Gas station',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/46.gif'
          },
          {
            'number' => '47',
            'unicode' => 'E66C',
            'name' => '駐車場',
            'sjis' => 'F8CD',
            'name_en' => 'Parking',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/47.gif'
          },
          {
            'number' => '48',
            'unicode' => 'E66D',
            'name' => '信号',
            'sjis' => 'F8CE',
            'name_en' => 'Traffic signal',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/48.gif'
          },
          {
            'number' => '49',
            'unicode' => 'E66E',
            'name' => 'トイレ',
            'sjis' => 'F8CF',
            'name_en' => 'Toilet',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/49.gif'
          },
          {
            'number' => '50',
            'unicode' => 'E66F',
            'name' => 'レストラン',
            'sjis' => 'F8D0',
            'name_en' => 'Restaurant',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/50.gif'
          },
          {
            'number' => '51',
            'unicode' => 'E670',
            'name' => '喫茶店',
            'sjis' => 'F8D1',
            'name_en' => 'Café',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/51.gif'
          },
          {
            'number' => '52',
            'unicode' => 'E671',
            'name' => 'バー',
            'sjis' => 'F8D2',
            'name_en' => 'Bar',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/52.gif'
          },
          {
            'number' => '53',
            'unicode' => 'E672',
            'name' => 'ビール',
            'sjis' => 'F8D3',
            'name_en' => 'Beer',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/53.gif'
          },
          {
            'number' => '54',
            'unicode' => 'E673',
            'name' => 'ファーストフード',
            'sjis' => 'F8D4',
            'name_en' => 'Fast food',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/54.gif'
          },
          {
            'number' => '55',
            'unicode' => 'E674',
            'name' => 'ブティック',
            'sjis' => 'F8D5',
            'name_en' => 'Boutique',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/55.gif'
          },
          {
            'number' => '56',
            'unicode' => 'E675',
            'name' => '美容院',
            'sjis' => 'F8D6',
            'name_en' => 'Hairdresser',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/56.gif'
          },
          {
            'number' => '57',
            'unicode' => 'E676',
            'name' => 'カラオケ',
            'sjis' => 'F8D7',
            'name_en' => 'Karaoke',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/57.gif'
          },
          {
            'number' => '58',
            'unicode' => 'E677',
            'name' => '映画',
            'sjis' => 'F8D8',
            'name_en' => 'Movie',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/58.gif'
          },
          {
            'number' => '59',
            'unicode' => 'E678',
            'name' => '右斜め上',
            'sjis' => 'F8D9',
            'name_en' => 'Diagonally upward toward right',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/59.gif'
          },
          {
            'number' => '60',
            'unicode' => 'E679',
            'name' => '遊園地',
            'sjis' => 'F8DA',
            'name_en' => 'Amusement park',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/60.gif'
          },
          {
            'number' => '61',
            'unicode' => 'E67A',
            'name' => '音楽',
            'sjis' => 'F8DB',
            'name_en' => 'Music',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/61.gif'
          },
          {
            'number' => '62',
            'unicode' => 'E67B',
            'name' => 'アート',
            'sjis' => 'F8DC',
            'name_en' => 'Art',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/62.gif'
          },
          {
            'number' => '63',
            'unicode' => 'E67C',
            'name' => '演劇',
            'sjis' => 'F8DD',
            'name_en' => 'Drama',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/63.gif'
          },
          {
            'number' => '64',
            'unicode' => 'E67D',
            'name' => 'イベント',
            'sjis' => 'F8DE',
            'name_en' => 'Event',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/64.gif'
          },
          {
            'number' => '65',
            'unicode' => 'E67E',
            'name' => 'チケット',
            'sjis' => 'F8DF',
            'name_en' => 'Ticket',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/65.gif'
          },
          {
            'number' => '66',
            'unicode' => 'E67F',
            'name' => '喫煙',
            'sjis' => 'F8E0',
            'name_en' => 'Smoking',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/66.gif'
          },
          {
            'number' => '67',
            'unicode' => 'E680',
            'name' => '禁煙',
            'sjis' => 'F8E1',
            'name_en' => 'Non-smoking',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/67.gif'
          },
          {
            'number' => '68',
            'unicode' => 'E681',
            'name' => 'カメラ',
            'sjis' => 'F8E2',
            'name_en' => 'Camera',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/68.gif'
          },
          {
            'number' => '69',
            'unicode' => 'E682',
            'name' => 'カバン',
            'sjis' => 'F8E3',
            'name_en' => 'Bag',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/69.gif'
          },
          {
            'number' => '70',
            'unicode' => 'E683',
            'name' => '本',
            'sjis' => 'F8E4',
            'name_en' => 'Book',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/70.gif'
          },
          {
            'number' => '71',
            'unicode' => 'E684',
            'name' => 'リボン',
            'sjis' => 'F8E5',
            'name_en' => 'Ribbon',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/71.gif'
          },
          {
            'number' => '72',
            'unicode' => 'E685',
            'name' => 'プレゼント',
            'sjis' => 'F8E6',
            'name_en' => 'Present',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/72.gif'
          },
          {
            'number' => '73',
            'unicode' => 'E686',
            'name' => 'バースデー',
            'sjis' => 'F8E7',
            'name_en' => 'Birthday',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/73.gif'
          },
          {
            'number' => '74',
            'unicode' => 'E687',
            'name' => '電話',
            'sjis' => 'F8E8',
            'name_en' => 'Phone',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/74.gif'
          },
          {
            'number' => '75',
            'unicode' => 'E688',
            'name' => '携帯電話',
            'sjis' => 'F8E9',
            'name_en' => 'Mobile phone',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/75.gif'
          },
          {
            'number' => '76',
            'unicode' => 'E689',
            'name' => 'メモ',
            'sjis' => 'F8EA',
            'name_en' => 'Memo',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/76.gif'
          },
          {
            'number' => '77',
            'unicode' => 'E68A',
            'name' => 'ＴＶ',
            'sjis' => 'F8EB',
            'name_en' => 'TV',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/77.gif'
          },
          {
            'number' => '78',
            'unicode' => 'E68B',
            'name' => 'ゲーム',
            'sjis' => 'F8EC',
            'name_en' => 'Game',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/78.gif'
          },
          {
            'number' => '79',
            'unicode' => 'E68C',
            'name' => 'ＣＤ',
            'sjis' => 'F8ED',
            'name_en' => 'CD',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/79.gif'
          },
          {
            'number' => '80',
            'unicode' => 'E68D',
            'name' => 'ハート',
            'sjis' => 'F8EE',
            'name_en' => 'Heart',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/80.gif'
          },
          {
            'number' => '81',
            'unicode' => 'E68E',
            'name' => 'スペード',
            'sjis' => 'F8EF',
            'name_en' => 'Spade',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/81.gif'
          },
          {
            'number' => '82',
            'unicode' => 'E68F',
            'name' => 'ダイヤ',
            'sjis' => 'F8F0',
            'name_en' => 'Diamond',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/82.gif'
          },
          {
            'number' => '83',
            'unicode' => 'E690',
            'name' => 'クラブ',
            'sjis' => 'F8F1',
            'name_en' => 'Club',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/83.gif'
          },
          {
            'number' => '84',
            'unicode' => 'E691',
            'name' => '目',
            'sjis' => 'F8F2',
            'name_en' => 'Eyes',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/84.gif'
          },
          {
            'number' => '85',
            'unicode' => 'E692',
            'name' => '耳',
            'sjis' => 'F8F3',
            'name_en' => 'Ear',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/85.gif'
          },
          {
            'number' => '86',
            'unicode' => 'E693',
            'name' => '手（グー）',
            'sjis' => 'F8F4',
            'name_en' => 'Hand (rock)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/86.gif'
          },
          {
            'number' => '87',
            'unicode' => 'E694',
            'name' => '手（チョキ）',
            'sjis' => 'F8F5',
            'name_en' => 'Hand (scissors)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/87.gif'
          },
          {
            'number' => '88',
            'unicode' => 'E695',
            'name' => '手（パー）',
            'sjis' => 'F8F6',
            'name_en' => 'Hand (paper)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/88.gif'
          },
          {
            'number' => '89',
            'unicode' => 'E696',
            'name' => '右斜め下',
            'sjis' => 'F8F7',
            'name_en' => 'Diagonally downward toward right',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/89.gif'
          },
          {
            'number' => '90',
            'unicode' => 'E697',
            'name' => '左斜め上',
            'sjis' => 'F8F8',
            'name_en' => 'Diagonally upward toward left',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/90.gif'
          },
          {
            'number' => '91',
            'unicode' => 'E698',
            'name' => '足',
            'sjis' => 'F8F9',
            'name_en' => 'Foot',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/91.gif'
          },
          {
            'number' => '92',
            'unicode' => 'E699',
            'name' => 'くつ',
            'sjis' => 'F8FA',
            'name_en' => 'Shoe',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/92.gif'
          },
          {
            'number' => '93',
            'unicode' => 'E69A',
            'name' => '眼鏡',
            'sjis' => 'F8FB',
            'name_en' => 'Eyeglasses',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/93.gif'
          },
          {
            'number' => '94',
            'unicode' => 'E69B',
            'name' => '車椅子',
            'sjis' => 'F8FC',
            'name_en' => 'Wheelchair',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/94.gif'
          },
          {
            'number' => '95',
            'unicode' => 'E69C',
            'name' => '新月',
            'sjis' => 'F940',
            'name_en' => 'New moon',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/95.gif'
          },
          {
            'number' => '96',
            'unicode' => 'E69D',
            'name' => 'やや欠け月',
            'sjis' => 'F941',
            'name_en' => 'Waning moon',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/96.gif'
          },
          {
            'number' => '97',
            'unicode' => 'E69E',
            'name' => '半月',
            'sjis' => 'F942',
            'name_en' => 'Half moon',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/97.gif'
          },
          {
            'number' => '98',
            'unicode' => 'E69F',
            'name' => '三日月',
            'sjis' => 'F943',
            'name_en' => 'Crescent moon',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/98.gif'
          },
          {
            'number' => '99',
            'unicode' => 'E6A0',
            'name' => '満月',
            'sjis' => 'F944',
            'name_en' => 'Full moon',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/99.gif'
          },
          {
            'number' => '100',
            'unicode' => 'E6A1',
            'name' => '犬',
            'sjis' => 'F945',
            'name_en' => 'Dog',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/100.gif'
          },
          {
            'number' => '101',
            'unicode' => 'E6A2',
            'name' => '猫',
            'sjis' => 'F946',
            'name_en' => 'Cat',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/101.gif'
          },
          {
            'number' => '102',
            'unicode' => 'E6A3',
            'name' => 'リゾート',
            'sjis' => 'F947',
            'name_en' => 'Resort',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/102.gif'
          },
          {
            'number' => '103',
            'unicode' => 'E6A4',
            'name' => 'クリスマス',
            'sjis' => 'F948',
            'name_en' => 'Christmas',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/103.gif'
          },
          {
            'number' => '104',
            'unicode' => 'E6A5',
            'name' => '左斜め下',
            'sjis' => 'F949',
            'name_en' => 'Diagonally downward toward left',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/104.gif'
          },
          {
            'number' => '105',
            'unicode' => 'E6CE',
            'name' => 'phone to',
            'sjis' => 'F972',
            'name_en' => 'Phone to',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/105.gif'
          },
          {
            'number' => '106',
            'unicode' => 'E6CF',
            'name' => 'mail to',
            'sjis' => 'F973',
            'name_en' => 'mail to',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/106.gif'
          },
          {
            'number' => '107',
            'unicode' => 'E6D0',
            'name' => 'fax to',
            'sjis' => 'F974',
            'name_en' => 'fax to',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/107.gif'
          },
          {
            'number' => '108',
            'unicode' => 'E6D1',
            'name' => 'iモード',
            'sjis' => 'F975',
            'name_en' => 'i-mode',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/108.gif'
          },
          {
            'number' => '109',
            'unicode' => 'E6D2',
            'name' => 'iモード（枠付き）',
            'sjis' => 'F976',
            'name_en' => 'i-mode with frame',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/109.gif'
          },
          {
            'number' => '110',
            'unicode' => 'E6D3',
            'name' => 'メール',
            'sjis' => 'F977',
            'name_en' => 'Mail',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/110.gif'
          },
          {
            'number' => '111',
            'unicode' => 'E6D4',
            'name' => 'ドコモ提供',
            'sjis' => 'F978',
            'name_en' => 'Provided by DoCoMo',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/111.gif'
          },
          {
            'number' => '112',
            'unicode' => 'E6D5',
            'name' => 'ドコモポイント',
            'sjis' => 'F979',
            'name_en' => 'DoCoMo point',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/112.gif'
          },
          {
            'number' => '113',
            'unicode' => 'E6D6',
            'name' => '有料',
            'sjis' => 'F97A',
            'name_en' => 'Fee charging',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/113.gif'
          },
          {
            'number' => '114',
            'unicode' => 'E6D7',
            'name' => '無料',
            'sjis' => 'F97B',
            'name_en' => 'Free of charge',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/114.gif'
          },
          {
            'number' => '115',
            'unicode' => 'E6D8',
            'name' => 'ID',
            'sjis' => 'F97C',
            'name_en' => 'ID',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/115.gif'
          },
          {
            'number' => '116',
            'unicode' => 'E6D9',
            'name' => 'パスワード',
            'sjis' => 'F97D',
            'name_en' => 'Password',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/116.gif'
          },
          {
            'number' => '117',
            'unicode' => 'E6DA',
            'name' => '次項有',
            'sjis' => 'F97E',
            'name_en' => 'Continuing',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/117.gif'
          },
          {
            'number' => '118',
            'unicode' => 'E6DB',
            'name' => 'クリア',
            'sjis' => 'F980',
            'name_en' => 'Clear',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/118.gif'
          },
          {
            'number' => '119',
            'unicode' => 'E6DC',
            'name' => 'サーチ（調べる）',
            'sjis' => 'F981',
            'name_en' => 'Search',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/119.gif'
          },
          {
            'number' => '120',
            'unicode' => 'E6DD',
            'name' => 'ＮＥＷ',
            'sjis' => 'F982',
            'name_en' => 'New',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/120.gif'
          },
          {
            'number' => '121',
            'unicode' => 'E6DE',
            'name' => '位置情報',
            'sjis' => 'F983',
            'name_en' => 'Location information',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/121.gif'
          },
          {
            'number' => '122',
            'unicode' => 'E6DF',
            'name' => 'フリーダイヤル',
            'sjis' => 'F984',
            'name_en' => 'Free dial',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/122.gif'
          },
          {
            'number' => '123',
            'unicode' => 'E6E0',
            'name' => 'シャープダイヤル',
            'sjis' => 'F985',
            'name_en' => 'Sharp dial',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/123.gif'
          },
          {
            'number' => '124',
            'unicode' => 'E6E1',
            'name' => 'モバＱ',
            'sjis' => 'F986',
            'name_en' => 'MobileQ',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/124.gif'
          },
          {
            'number' => '125',
            'unicode' => 'E6E2',
            'name' => '1',
            'sjis' => 'F987',
            'name_en' => '1',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/125.gif'
          },
          {
            'number' => '126',
            'unicode' => 'E6E3',
            'name' => '2',
            'sjis' => 'F988',
            'name_en' => '2',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/126.gif'
          },
          {
            'number' => '127',
            'unicode' => 'E6E4',
            'name' => '3',
            'sjis' => 'F989',
            'name_en' => '3',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/127.gif'
          },
          {
            'number' => '128',
            'unicode' => 'E6E5',
            'name' => '4',
            'sjis' => 'F98A',
            'name_en' => '4',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/128.gif'
          },
          {
            'number' => '129',
            'unicode' => 'E6E6',
            'name' => '5',
            'sjis' => 'F98B',
            'name_en' => '5',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/129.gif'
          },
          {
            'number' => '130',
            'unicode' => 'E6E7',
            'name' => '6',
            'sjis' => 'F98C',
            'name_en' => '6',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/130.gif'
          },
          {
            'number' => '131',
            'unicode' => 'E6E8',
            'name' => '7',
            'sjis' => 'F98D',
            'name_en' => '7',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/131.gif'
          },
          {
            'number' => '132',
            'unicode' => 'E6E9',
            'name' => '8',
            'sjis' => 'F98E',
            'name_en' => '8',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/132.gif'
          },
          {
            'number' => '133',
            'unicode' => 'E6EA',
            'name' => '9',
            'sjis' => 'F98F',
            'name_en' => '9',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/133.gif'
          },
          {
            'number' => '134',
            'unicode' => 'E6EB',
            'name' => '0',
            'sjis' => 'F990',
            'name_en' => '0',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/134.gif'
          },
          {
            'number' => '135',
            'unicode' => 'E70B',
            'name' => '決定',
            'sjis' => 'F9B0',
            'name_en' => 'Accept',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/135.gif'
          },
          {
            'number' => '136',
            'unicode' => 'E6EC',
            'name' => '黒ハート',
            'sjis' => 'F991',
            'name_en' => 'Black heart',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/136.gif'
          },
          {
            'number' => '137',
            'unicode' => 'E6ED',
            'name' => '揺れるハート',
            'sjis' => 'F992',
            'name_en' => 'Fluttering heart',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/137.gif'
          },
          {
            'number' => '138',
            'unicode' => 'E6EE',
            'name' => '失恋',
            'sjis' => 'F993',
            'name_en' => 'Heartbreak',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/138.gif'
          },
          {
            'number' => '139',
            'unicode' => 'E6EF',
            'name' => 'ハートたち（複数ハート）',
            'sjis' => 'F994',
            'name_en' => 'Hearts',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/139.gif'
          },
          {
            'number' => '140',
            'unicode' => 'E6F0',
            'name' => 'わーい（嬉しい顔）',
            'sjis' => 'F995',
            'name_en' => 'Happy face',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/140.gif'
          },
          {
            'number' => '141',
            'unicode' => 'E6F1',
            'name' => 'ちっ（怒った顔）',
            'sjis' => 'F996',
            'name_en' => 'Angry face',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/141.gif'
          },
          {
            'number' => '142',
            'unicode' => 'E6F2',
            'name' => 'がく〜（落胆した顔）',
            'sjis' => 'F997',
            'name_en' => 'Disappointed face',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/142.gif'
          },
          {
            'number' => '143',
            'unicode' => 'E6F3',
            'name' => 'もうやだ〜（悲しい顔）',
            'sjis' => 'F998',
            'name_en' => 'Sad face',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/143.gif'
          },
          {
            'number' => '144',
            'unicode' => 'E6F4',
            'name' => 'ふらふら',
            'sjis' => 'F999',
            'name_en' => 'Dizzy',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/144.gif'
          },
          {
            'number' => '145',
            'unicode' => 'E6F5',
            'name' => 'グッド（上向き矢印）',
            'sjis' => 'F99A',
            'name_en' => 'Good (upward arrow)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/145.gif'
          },
          {
            'number' => '146',
            'unicode' => 'E6F6',
            'name' => 'るんるん',
            'sjis' => 'F99B',
            'name_en' => 'Cheerful',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/146.gif'
          },
          {
            'number' => '147',
            'unicode' => 'E6F7',
            'name' => 'いい気分（温泉）',
            'sjis' => 'F99C',
            'name_en' => 'Comfort (hot spring)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/147.gif'
          },
          {
            'number' => '148',
            'unicode' => 'E6F8',
            'name' => 'かわいい',
            'sjis' => 'F99D',
            'name_en' => 'Cute',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/148.gif'
          },
          {
            'number' => '149',
            'unicode' => 'E6F9',
            'name' => 'キスマーク',
            'sjis' => 'F99E',
            'name_en' => 'Kiss',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/149.gif'
          },
          {
            'number' => '150',
            'unicode' => 'E6FA',
            'name' => 'ぴかぴか（新しい）',
            'sjis' => 'F99F',
            'name_en' => 'Shining new',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/150.gif'
          },
          {
            'number' => '151',
            'unicode' => 'E6FB',
            'name' => 'ひらめき',
            'sjis' => 'F9A0',
            'name_en' => 'Good idea',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/151.gif'
          },
          {
            'number' => '152',
            'unicode' => 'E6FC',
            'name' => 'むかっ（怒り）',
            'sjis' => 'F9A1',
            'name_en' => 'Angry',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/152.gif'
          },
          {
            'number' => '153',
            'unicode' => 'E6FD',
            'name' => 'パンチ',
            'sjis' => 'F9A2',
            'name_en' => 'Punch',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/153.gif'
          },
          {
            'number' => '154',
            'unicode' => 'E6FE',
            'name' => '爆弾',
            'sjis' => 'F9A3',
            'name_en' => 'Bomb',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/154.gif'
          },
          {
            'number' => '155',
            'unicode' => 'E6FF',
            'name' => 'ムード',
            'sjis' => 'F9A4',
            'name_en' => 'Mood',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/155.gif'
          },
          {
            'number' => '156',
            'unicode' => 'E700',
            'name' => 'バッド（下向き矢印）',
            'sjis' => 'F9A5',
            'name_en' => 'Bad (downward arrow)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/156.gif'
          },
          {
            'number' => '157',
            'unicode' => 'E701',
            'name' => '眠い(睡眠)',
            'sjis' => 'F9A6',
            'name_en' => 'Sleepy (sleep)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/157.gif'
          },
          {
            'number' => '158',
            'unicode' => 'E702',
            'name' => 'exclamation',
            'sjis' => 'F9A7',
            'name_en' => 'Exclamation mark',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/158.gif'
          },
          {
            'number' => '159',
            'unicode' => 'E703',
            'name' => 'exclamation&question',
            'sjis' => 'F9A8',
            'name_en' => 'exclamation&question marks',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/159.gif'
          },
          {
            'number' => '160',
            'unicode' => 'E704',
            'name' => 'exclamation×2',
            'sjis' => 'F9A9',
            'name_en' => 'Two exclamation marks',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/160.gif'
          },
          {
            'number' => '161',
            'unicode' => 'E705',
            'name' => 'どんっ（衝撃）',
            'sjis' => 'F9AA',
            'name_en' => 'Bump (collision)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/161.gif'
          },
          {
            'number' => '162',
            'unicode' => 'E706',
            'name' => 'あせあせ（飛び散る汗）',
            'sjis' => 'F9AB',
            'name_en' => 'Sweat',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/162.gif'
          },
          {
            'number' => '163',
            'unicode' => 'E707',
            'name' => 'たらーっ（汗）',
            'sjis' => 'F9AC',
            'name_en' => 'Cold sweat',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/163.gif'
          },
          {
            'number' => '164',
            'unicode' => 'E708',
            'name' => 'ダッシュ（走り出すさま）',
            'sjis' => 'F9AD',
            'name_en' => 'Dash (running dash)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/164.gif'
          },
          {
            'number' => '165',
            'unicode' => 'E709',
            'name' => 'ー（長音記号１）',
            'sjis' => 'F9AE',
            'name_en' => 'Macron 1',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/165.gif'
          },
          {
            'number' => '166',
            'unicode' => 'E70A',
            'name' => 'ー（長音記号２）',
            'sjis' => 'F9AF',
            'name_en' => 'Macron 2',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/166.gif'
          },
          {
            'number' => '167',
            'unicode' => 'E6AC',
            'name' => 'カチンコ',
            'sjis' => 'F950',
            'name_en' => 'Clapboard',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/167.gif'
          },
          {
            'number' => '168',
            'unicode' => 'E6AD',
            'name' => 'ふくろ',
            'sjis' => 'F951',
            'name_en' => 'Pouch',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/168.gif'
          },
          {
            'number' => '169',
            'unicode' => 'E6AE',
            'name' => 'ペン',
            'sjis' => 'F952',
            'name_en' => 'Pen',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/169.gif'
          },
          {
            'number' => '170',
            'unicode' => 'E6B1',
            'name' => '人影',
            'sjis' => 'F955',
            'name_en' => 'Silhouette',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/170.gif'
          },
          {
            'number' => '171',
            'unicode' => 'E6B2',
            'name' => 'いす',
            'sjis' => 'F956',
            'name_en' => 'Chair',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/171.gif'
          },
          {
            'number' => '172',
            'unicode' => 'E6B3',
            'name' => '夜',
            'sjis' => 'F957',
            'name_en' => 'Night',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/172.gif'
          },
          {
            'number' => '173',
            'unicode' => 'E6B7',
            'name' => 'soon',
            'sjis' => 'F95B',
            'name_en' => 'Soon',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/173.gif'
          },
          {
            'number' => '174',
            'unicode' => 'E6B8',
            'name' => 'on',
            'sjis' => 'F95C',
            'name_en' => 'on',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/174.gif'
          },
          {
            'number' => '175',
            'unicode' => 'E6B9',
            'name' => 'end',
            'sjis' => 'F95D',
            'name_en' => 'end',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/175.gif'
          },
          {
            'number' => '176',
            'unicode' => 'E6BA',
            'name' => '時計',
            'sjis' => 'F95E',
            'name_en' => 'Clock',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/basic/images/176.gif'
          },
          {
            'number' => '拡1',
            'unicode' => 'E70C',
            'name' => 'iアプリ',
            'sjis' => 'F9B1',
            'name_en' => 'i-αppli',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/1.gif'
          },
          {
            'number' => '拡2',
            'unicode' => 'E70D',
            'name' => 'iアプリ（枠付き）',
            'sjis' => 'F9B2',
            'name_en' => 'i-αppli (with border)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/2.gif'
          },
          {
            'number' => '拡3',
            'unicode' => 'E70E',
            'name' => 'Tシャツ（ボーダー）',
            'sjis' => 'F9B3',
            'name_en' => 'T-shirt (border)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/3.gif'
          },
          {
            'number' => '拡4',
            'unicode' => 'E70F',
            'name' => 'がま口財布',
            'sjis' => 'F9B4',
            'name_en' => 'Purse',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/4.gif'
          },
          {
            'number' => '拡5',
            'unicode' => 'E710',
            'name' => '化粧',
            'sjis' => 'F9B5',
            'name_en' => 'Make-up',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/5.gif'
          },
          {
            'number' => '拡6',
            'unicode' => 'E711',
            'name' => 'ジーンズ',
            'sjis' => 'F9B6',
            'name_en' => 'Jeans',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/6.gif'
          },
          {
            'number' => '拡7',
            'unicode' => 'E712',
            'name' => 'スノボ',
            'sjis' => 'F9B7',
            'name_en' => 'Snowboarding',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/7.gif'
          },
          {
            'number' => '拡8',
            'unicode' => 'E713',
            'name' => 'チャペル',
            'sjis' => 'F9B8',
            'name_en' => 'Chapel',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/8.gif'
          },
          {
            'number' => '拡9',
            'unicode' => 'E714',
            'name' => 'ドア',
            'sjis' => 'F9B9',
            'name_en' => 'Door',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/9.gif'
          },
          {
            'number' => '拡10',
            'unicode' => 'E715',
            'name' => 'ドル袋',
            'sjis' => 'F9BA',
            'name_en' => 'Money bag',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/10.gif'
          },
          {
            'number' => '拡11',
            'unicode' => 'E716',
            'name' => 'パソコン',
            'sjis' => 'F9BB',
            'name_en' => 'Computer',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/11.gif'
          },
          {
            'number' => '拡12',
            'unicode' => 'E717',
            'name' => 'ラブレター',
            'sjis' => 'F9BC',
            'name_en' => 'Love letter',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/12.gif'
          },
          {
            'number' => '拡13',
            'unicode' => 'E718',
            'name' => 'レンチ',
            'sjis' => 'F9BD',
            'name_en' => 'Wrench',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/13.gif'
          },
          {
            'number' => '拡14',
            'unicode' => 'E719',
            'name' => '鉛筆',
            'sjis' => 'F9BE',
            'name_en' => 'Pencil',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/14.gif'
          },
          {
            'number' => '拡15',
            'unicode' => 'E71A',
            'name' => '王冠',
            'sjis' => 'F9BF',
            'name_en' => 'Crown',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/15.gif'
          },
          {
            'number' => '拡16',
            'unicode' => 'E71B',
            'name' => '指輪',
            'sjis' => 'F9C0',
            'name_en' => 'Ring',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/16.gif'
          },
          {
            'number' => '拡17',
            'unicode' => 'E71C',
            'name' => '砂時計',
            'sjis' => 'F9C1',
            'name_en' => 'Sandglass',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/17.gif'
          },
          {
            'number' => '拡18',
            'unicode' => 'E71D',
            'name' => '自転車',
            'sjis' => 'F9C2',
            'name_en' => 'Bicycle',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/18.gif'
          },
          {
            'number' => '拡19',
            'unicode' => 'E71E',
            'name' => '湯のみ',
            'sjis' => 'F9C3',
            'name_en' => 'Tea cup',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/19.gif'
          },
          {
            'number' => '拡20',
            'unicode' => 'E71F',
            'name' => '腕時計',
            'sjis' => 'F9C4',
            'name_en' => 'Wrist watch',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/20.gif'
          },
          {
            'number' => '拡21',
            'unicode' => 'E720',
            'name' => '考えてる顔',
            'sjis' => 'F9C5',
            'name_en' => 'Thinking face',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/21.gif'
          },
          {
            'number' => '拡22',
            'unicode' => 'E721',
            'name' => 'ほっとした顔',
            'sjis' => 'F9C6',
            'name_en' => 'Relief face',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/22.gif'
          },
          {
            'number' => '拡23',
            'unicode' => 'E722',
            'name' => '冷や汗',
            'sjis' => 'F9C7',
            'name_en' => 'Cold sweat',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/23.gif'
          },
          {
            'number' => '拡24',
            'unicode' => 'E723',
            'name' => '冷や汗2',
            'sjis' => 'F9C8',
            'name_en' => 'Cold sweat 2',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/24.gif'
          },
          {
            'number' => '拡25',
            'unicode' => 'E724',
            'name' => 'ぷっくっくな顔',
            'sjis' => 'F9C9',
            'name_en' => 'Pouting face',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/25.gif'
          },
          {
            'number' => '拡26',
            'unicode' => 'E725',
            'name' => 'ボケーっとした顔',
            'sjis' => 'F9CA',
            'name_en' => 'Expressionless face',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/26.gif'
          },
          {
            'number' => '拡27',
            'unicode' => 'E726',
            'name' => '目がハート',
            'sjis' => 'F9CB',
            'name_en' => 'Heart shaped eyes',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/27.gif'
          },
          {
            'number' => '拡28',
            'unicode' => 'E727',
            'name' => '指でOK',
            'sjis' => 'F9CC',
            'name_en' => 'Thumbs up',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/28.gif'
          },
          {
            'number' => '拡29',
            'unicode' => 'E728',
            'name' => 'あっかんべー',
            'sjis' => 'F9CD',
            'name_en' => 'Sticking tongue out',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/29.gif'
          },
          {
            'number' => '拡30',
            'unicode' => 'E729',
            'name' => 'ウィンク',
            'sjis' => 'F9CE',
            'name_en' => 'Wink',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/30.gif'
          },
          {
            'number' => '拡31',
            'unicode' => 'E72A',
            'name' => 'うれしい顔',
            'sjis' => 'F9CF',
            'name_en' => 'Happy face',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/31.gif'
          },
          {
            'number' => '拡32',
            'unicode' => 'E72B',
            'name' => 'がまん顔',
            'sjis' => 'F9D0',
            'name_en' => 'Enduring face',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/32.gif'
          },
          {
            'number' => '拡33',
            'unicode' => 'E72C',
            'name' => '猫2',
            'sjis' => 'F9D1',
            'name_en' => 'Cat 2',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/33.gif'
          },
          {
            'number' => '拡34',
            'unicode' => 'E72D',
            'name' => '泣き顔',
            'sjis' => 'F9D2',
            'name_en' => 'Crying',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/34.gif'
          },
          {
            'number' => '拡35',
            'unicode' => 'E72E',
            'name' => '涙',
            'sjis' => 'F9D3',
            'name_en' => 'Tear',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/35.gif'
          },
          {
            'number' => '拡36',
            'unicode' => 'E72F',
            'name' => 'NG',
            'sjis' => 'F9D4',
            'name_en' => 'NG (No good)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/36.gif'
          },
          {
            'number' => '拡37',
            'unicode' => 'E730',
            'name' => 'クリップ',
            'sjis' => 'F9D5',
            'name_en' => 'Paper clip',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/37.gif'
          },
          {
            'number' => '拡38',
            'unicode' => 'E731',
            'name' => 'コピーライト',
            'sjis' => 'F9D6',
            'name_en' => 'Copyright',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/38.gif'
          },
          {
            'number' => '拡39',
            'unicode' => 'E732',
            'name' => 'トレードマーク',
            'sjis' => 'F9D7',
            'name_en' => 'Trademark',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/39.gif'
          },
          {
            'number' => '拡40',
            'unicode' => 'E733',
            'name' => '走る人',
            'sjis' => 'F9D8',
            'name_en' => 'Running man',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/40.gif'
          },
          {
            'number' => '拡41',
            'unicode' => 'E734',
            'name' => 'マル秘',
            'sjis' => 'F9D9',
            'name_en' => 'Top secret',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/41.gif'
          },
          {
            'number' => '拡42',
            'unicode' => 'E735',
            'name' => 'リサイクル',
            'sjis' => 'F9DA',
            'name_en' => 'Recycle',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/42.gif'
          },
          {
            'number' => '拡43',
            'unicode' => 'E736',
            'name' => 'レジスタードトレードマーク',
            'sjis' => 'F9DB',
            'name_en' => 'Registered trademark',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/43.gif'
          },
          {
            'number' => '拡44',
            'unicode' => 'E737',
            'name' => '危険・警告',
            'sjis' => 'F9DC',
            'name_en' => 'Danger / Caution',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/44.gif'
          },
          {
            'number' => '拡45',
            'unicode' => 'E738',
            'name' => '禁止',
            'sjis' => 'F9DD',
            'name_en' => 'Prohibited',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/45.gif'
          },
          {
            'number' => '拡46',
            'unicode' => 'E739',
            'name' => '空室・空席・空車',
            'sjis' => 'F9DE',
            'name_en' => 'Vacant',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/46.gif'
          },
          {
            'number' => '拡47',
            'unicode' => 'E73A',
            'name' => '合格マーク',
            'sjis' => 'F9DF',
            'name_en' => 'Approved',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/47.gif'
          },
          {
            'number' => '拡48',
            'unicode' => 'E73B',
            'name' => '満室・満席・満車',
            'sjis' => 'F9E0',
            'name_en' => 'Full',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/48.gif'
          },
          {
            'number' => '拡49',
            'unicode' => 'E73C',
            'name' => '矢印左右',
            'sjis' => 'F9E1',
            'name_en' => 'Horizontal arrows',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/49.gif'
          },
          {
            'number' => '拡50',
            'unicode' => 'E73D',
            'name' => '矢印上下',
            'sjis' => 'F9E2',
            'name_en' => 'Vertical arrows',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/50.gif'
          },
          {
            'number' => '拡51',
            'unicode' => 'E73E',
            'name' => '学校',
            'sjis' => 'F9E3',
            'name_en' => 'School',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/51.gif'
          },
          {
            'number' => '拡52',
            'unicode' => 'E73F',
            'name' => '波',
            'sjis' => 'F9E4',
            'name_en' => 'Wave',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/52.gif'
          },
          {
            'number' => '拡53',
            'unicode' => 'E740',
            'name' => '富士山',
            'sjis' => 'F9E5',
            'name_en' => 'Mount Fuji',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/53.gif'
          },
          {
            'number' => '拡54',
            'unicode' => 'E741',
            'name' => 'クローバー',
            'sjis' => 'F9E6',
            'name_en' => '4-leaf clover',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/54.gif'
          },
          {
            'number' => '拡55',
            'unicode' => 'E742',
            'name' => 'さくらんぼ',
            'sjis' => 'F9E7',
            'name_en' => 'Cherries',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/55.gif'
          },
          {
            'number' => '拡56',
            'unicode' => 'E743',
            'name' => 'チューリップ',
            'sjis' => 'F9E8',
            'name_en' => 'Tulip',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/56.gif'
          },
          {
            'number' => '拡57',
            'unicode' => 'E744',
            'name' => 'バナナ',
            'sjis' => 'F9E9',
            'name_en' => 'Banana',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/57.gif'
          },
          {
            'number' => '拡58',
            'unicode' => 'E745',
            'name' => 'りんご',
            'sjis' => 'F9EA',
            'name_en' => 'Apple',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/58.gif'
          },
          {
            'number' => '拡59',
            'unicode' => 'E746',
            'name' => '芽',
            'sjis' => 'F9EB',
            'name_en' => 'Seedling',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/59.gif'
          },
          {
            'number' => '拡60',
            'unicode' => 'E747',
            'name' => 'もみじ',
            'sjis' => 'F9EC',
            'name_en' => 'Maple leaf',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/60.gif'
          },
          {
            'number' => '拡61',
            'unicode' => 'E748',
            'name' => '桜',
            'sjis' => 'F9ED',
            'name_en' => 'Cherry blossom',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/61.gif'
          },
          {
            'number' => '拡62',
            'unicode' => 'E749',
            'name' => 'おにぎり',
            'sjis' => 'F9EE',
            'name_en' => 'Rice ball',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/62.gif'
          },
          {
            'number' => '拡63',
            'unicode' => 'E74A',
            'name' => 'ショートケーキ',
            'sjis' => 'F9EF',
            'name_en' => 'Short cake',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/63.gif'
          },
          {
            'number' => '拡64',
            'unicode' => 'E74B',
            'name' => 'とっくり（おちょこ付き）',
            'sjis' => 'F9F0',
            'name_en' => 'Sake bottle (sake cup)',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/64.gif'
          },
          {
            'number' => '拡65',
            'unicode' => 'E74C',
            'name' => 'どんぶり',
            'sjis' => 'F9F1',
            'name_en' => 'Bowl',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/65.gif'
          },
          {
            'number' => '拡66',
            'unicode' => 'E74D',
            'name' => 'パン',
            'sjis' => 'F9F2',
            'name_en' => 'Bread',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/66.gif'
          },
          {
            'number' => '拡67',
            'unicode' => 'E74E',
            'name' => 'かたつむり',
            'sjis' => 'F9F3',
            'name_en' => 'Snail',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/67.gif'
          },
          {
            'number' => '拡68',
            'unicode' => 'E74F',
            'name' => 'ひよこ',
            'sjis' => 'F9F4',
            'name_en' => 'Baby chick',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/68.gif'
          },
          {
            'number' => '拡69',
            'unicode' => 'E750',
            'name' => 'ペンギン',
            'sjis' => 'F9F5',
            'name_en' => 'Penguin',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/69.gif'
          },
          {
            'number' => '拡70',
            'unicode' => 'E751',
            'name' => '魚',
            'sjis' => 'F9F6',
            'name_en' => 'Fish',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/70.gif'
          },
          {
            'number' => '拡71',
            'unicode' => 'E752',
            'name' => 'うまい！',
            'sjis' => 'F9F7',
            'name_en' => 'Yumm!',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/71.gif'
          },
          {
            'number' => '拡72',
            'unicode' => 'E753',
            'name' => 'ウッシッシ',
            'sjis' => 'F9F8',
            'name_en' => 'He he he',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/72.gif'
          },
          {
            'number' => '拡73',
            'unicode' => 'E754',
            'name' => 'ウマ',
            'sjis' => 'F9F9',
            'name_en' => 'Horse',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/73.gif'
          },
          {
            'number' => '拡74',
            'unicode' => 'E755',
            'name' => 'ブタ',
            'sjis' => 'F9FA',
            'name_en' => 'Pig',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/74.gif'
          },
          {
            'number' => '拡75',
            'unicode' => 'E756',
            'name' => 'ワイングラス',
            'sjis' => 'F9FB',
            'name_en' => 'Wine glass',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/75.gif'
          },
          {
            'number' => '拡76',
            'unicode' => 'E757',
            'name' => 'げっそり',
            'sjis' => 'F9FC',
            'name_en' => 'Very thin',
            'image' => 'http://www.nttdocomo.co.jp/service/imode/make/content/pictograph/extention/images/76.gif'
          }
        ]
